import { StreamClient, APIResponse, UnknownRecord } from './client';
export declare type UserAPIResponse<UserType extends UnknownRecord = UnknownRecord> = APIResponse & {
    created_at: string;
    data: UserType;
    id: string;
    updated_at: string;
    followers_count?: number;
    following_count?: number;
};
export declare class StreamUser<UserType extends UnknownRecord = UnknownRecord> {
    client: StreamClient;
    token: string;
    id: string;
    data?: UserType;
    full?: UserAPIResponse<UserType>;
    private url;
    /**
     * Initialize a user session object
     * @method constructor
     * @memberof StreamUser.prototype
     * @param {StreamClient} client Stream client this collection is constructed from
     * @param {string} userId The ID of the user
     * @param {string} userAuthToken JWT token
     * @example new StreamUser(client, "123", "eyJhbGciOiJIUzI1...")
     */
    constructor(client: StreamClient, userId: string, userAuthToken: string);
    ref(): string;
    delete(): Promise<APIResponse>;
    get(options?: {
        with_follow_counts?: boolean;
    }): Promise<this>;
    create(data?: UserType, options?: {
        get_or_create?: boolean;
    }): Promise<this>;
    update(data?: Partial<UserType>): Promise<this>;
    getOrCreate(data: UserType): Promise<this>;
    profile(): Promise<this>;
}
//# sourceMappingURL=user.d.ts.map